@@ -9,7 +9,7 @@ except ModuleNotFoundError:
 
 from .. import base, exc
 from .._asymmetric import OAEP, PSS, MGF1
-from ._hashes import Hash
+from .Hash import Hash
 from ._serialization import encodings, formats, protection_schemes
 
 paddings = {
@@ -28,44 +28,16 @@ class _RSAKey:
     def e(self):
         return self._key.e
 
-    @classmethod
-    def load(cls, data, password=None):
-        """Loads the public or private key as `bytes` object
-        and returns the Key interface.
-
-        Args:
-            data:
-                The key as bytes object.
-            password:
-                The password that deserializes the private key.
-                `password` must be a `bytes` object if the key
-                was encrypted while serialization, otherwise `None`.
-                `password` has no meaning for public key.
-
-        Returns:
-            RSAPrivateKey or RSAPublicKey interface depending upon the
-            key.
-
-        Raises:
-            ValueError if the key could  not be deserialized.
-        """
-        try:
-            return cls(key=RSA.import_key(data, password))
-        except ValueError as e:
-            raise ValueError(
-                'Cannot deserialize key. '
-                'Either Key format is invalid or '
-                'password is missing or incorrect.', ) from e
-
 
 class RSAPrivateKey(_RSAKey, base.BasePrivateKey):
     """RSA private key wrapper class."""
+
     def __init__(self, n=None, e=65537, **kwargs):
         if kwargs:
-            self._key = kwargs.pop('key')
+            self._key = kwargs.pop("key")
         else:
             if n is None:
-                raise ValueError('RSA modulus not provided')
+                raise ValueError("RSA modulus not provided")
             self._key = RSA.generate(n, e=e)
 
     @property
@@ -91,7 +63,8 @@ class RSAPrivateKey(_RSAKey, base.BasePrivateKey):
             padding: The padding to use. Default is OAEP.
 
         Returns:
-            RSADecryptionCtx for decrypting ciphertexts.
+            :any:`RSADecryptionCtx`:
+                `RSADecryptionCtx` object for decrypting ciphertexts.
         """
         return RSADecryptionCtx(self._key, padding)
 
@@ -102,41 +75,41 @@ class RSAPrivateKey(_RSAKey, base.BasePrivateKey):
             padding: The padding to use. Default is PSS.
 
         Returns:
-            A RSASignerCtx object for signing messages.
+            :any:`RSASignerCtx`:
+                A :any:`RSASignerCtx` object for signing messages.
         """
         return RSASignerCtx(self._key, padding)
 
     def public_key(self):
         """Creates a public key from the private key
 
-        Args:
-            None
-
         Returns:
-            RSAPublicKey interface.
+            :any:`RSAPublicKey`: :any:`RSAPublicKey` interface.
         """
         return RSAPublicKey(self._key.publickey())
 
-    def serialize(self,
-                  encoding='PEM',
-                  format='PKCS8',
-                  passphrase=None,
-                  *,
-                  protection=None):
+    def serialize(
+        self,
+        encoding="PEM",
+        format="PKCS8",
+        passphrase=None,
+        *,
+        protection=None
+    ):
         """Serialize the private key.
 
         Args:
-            encoding:
+            encoding (str):
                 PEM or DER (defaults to PEM).
-            format:
+            format (str):
                 PKCS1 or PKCS8 (defaults to PKCS8).
-            passphrase:
+            passphrase (bytes, bytearray, memoryview):
                 a bytes object to use for encrypting the private key.
                 If `passphrase` is None, the private key will be exported
                 in the clear!
 
-        Kwargs:
-            protection:
+        Keyword Arguments:
+            protection (str):
                 The protection scheme to use.
 
                 Supplying a value for protection has meaning only if the
@@ -145,43 +118,78 @@ class RSAPrivateKey(_RSAKey, base.BasePrivateKey):
                 scheme.
 
         Returns:
-            Serialized key as a bytes object.
+            bytes: Serialized key as a bytes object.
 
         Raises:
             ValueError:
-                If the encoding is incorrect or,
-                if DER is used with PKCS1 or protection value
-                is supplied with PKCS1 format.
+                If the encoding is incorrect or, if DER is used
+                with PKCS1 or protection value is supplied with
+                PKCS1 format.
             KeyError: if the format is invalid or not supported.
-       """
-        if encoding not in encodings.keys() ^ {'OpenSSH'}:
-            raise ValueError('encoding must be PEM or DER')
+        """
+        if encoding not in encodings.keys() ^ {"OpenSSH"}:
+            raise ValueError("encoding must be PEM or DER")
 
         if protection is not None:
             if protection not in protection_schemes:
-                raise ValueError('invalid protection scheme')
+                raise ValueError("invalid protection scheme")
 
-        if format == 'PKCS1':
+        if format == "PKCS1":
             if protection is not None:
-                raise ValueError('protection is meaningful only for PKCS8')
-            if encoding == 'DER':
-                raise ValueError('cannot use DER with PKCS1 format')
+                raise ValueError("protection is meaningful only for PKCS8")
+            if encoding == "DER":
+                raise ValueError("cannot use DER with PKCS1 format")
 
         if passphrase is not None and protection is None:
             # use a curated encryption choice and not DES-EDE3-CBC
-            protection = 'PBKDF2WithHMAC-SHA1AndAES256-CBC'
+            protection = "PBKDF2WithHMAC-SHA1AndAES256-CBC"
 
         return self._key.export_key(
             format=encodings[encoding],
             pkcs=formats[format],
-            passphrase=(memoryview(passphrase).tobytes()
-                        if passphrase is not None else None),
+            passphrase=(
+                memoryview(passphrase).tobytes()
+                if passphrase is not None
+                else None
+            ),
             protection=protection,
         )
 
+    @classmethod
+    def load(cls, data, password=None):
+        """Loads the private key as `bytes` object and returns the
+        Key interface.
+
+        Args:
+            data (bytes):
+                The key as bytes object.
+            password (bytes, bytearray, memoryview):
+                The password that deserializes the private key. `password`
+                must be a `bytes` object if the key was encrypted while
+                serialization, otherwise `None`.
+
+        Returns:
+            :any:`RSAPrivateKey`: `RSAPrivateKey` key object.
+
+        Raises:
+            ValueError: if the key could not be deserialized.
+        """
+        try:
+            key = RSA.import_key(data, password)
+            if not key.has_private():
+                raise ValueError("The key is not a private key")
+            return cls(key=key)
+        except ValueError as e:
+            raise ValueError(
+                "Cannot deserialize key. "
+                "Either Key format is invalid or "
+                "password is missing or incorrect.",
+            ) from e
+
 
 class RSAPublicKey(_RSAKey, base.BasePublicKey):
     """RSA Public Key wrapper class."""
+
     def __init__(self, key):
         self._key = key
 
@@ -192,7 +200,8 @@ class RSAPublicKey(_RSAKey, base.BasePublicKey):
             padding: The padding to use. Defaults to OAEP.
 
         Returns:
-            An RSAEncryptionCtx encryption context object.
+            :any:`RSAEncryptionCtx`:
+                An `RSAEncryptionCtx` encryption context object.
         """
         return RSAEncryptionCtx(self._key, padding)
 
@@ -203,29 +212,56 @@ class RSAPublicKey(_RSAKey, base.BasePublicKey):
             padding: The padding to use. Defaults to ECC.
 
         Returns:
-            RSAVerifierCtx verification context object.
+            :any:`RSAVerifierCtx`:
+                `RSAVerifierCtx` verification context object.
         """
         return RSAVerifierCtx(self._key, padding)
 
-    def serialize(self, encoding='PEM'):
+    def serialize(self, encoding="PEM"):
         """Serialize the private key.
 
         Args:
-            encoding: PEM, DER or OpenSSH (defaults to PEM).
+            encoding (str): PEM, DER or OpenSSH (defaults to PEM).
 
         Returns:
-            The serialized public key as bytes object.
+            bytes: The serialized public key as bytes object.
 
         Raises:
             KeyError: if the encoding is not supported or invalid.
         """
         return self._key.export_key(format=encodings[encoding])
 
+    @classmethod
+    def load(cls, data):
+        """Loads the public key as `bytes` object and returns the
+        Key interface.
+
+        Args:
+            data (bytes):
+                The key as bytes object.
+
+        Returns:
+            :any:`RSAPublicKey`: `RSAPublicKey` key object.
+
+        Raises:
+            ValueError: if the key could not be deserialized.
+        """
+        try:
+            key = RSA.import_key(data)
+            if key.has_private():
+                raise ValueError("The key is not a public key")
+            return cls(key=key)
+        except ValueError as e:
+            raise ValueError(
+                "Cannot deserialize key. " "Key format might be invalid."
+            ) from e
+
 
 def _get_padding(pad):
     _pad = paddings[pad.__class__]
-    mhash = Hash(pad.mgf.hash.name,
-                 digest_size=pad.mgf.hash.digest_size)  # ._hasher
+    mhash = Hash(
+        pad.mgf.hash.name, digest_size=pad.mgf.hash.digest_size
+    )  # ._hasher
     _mgf = lambda x, y: paddings[pad.mgf.__class__](x, y, mhash)  # noqa: E731
     return _pad, _mgf
 
@@ -236,41 +272,40 @@ def _get_cipher(key, pad):
     return _pad(key, hashAlgo=phash, mgfunc=_mgf)
 
 
-class CipherContext:
+class _CipherContext:
     def __init__(self, key, padding):
         self._cipher = _get_cipher(key, padding)
 
 
-class RSAEncryptionCtx(CipherContext):
+class RSAEncryptionCtx(_CipherContext):
     def encrypt(self, plaintext):
         """Encrypts the plaintext and returns the ciphertext.
 
         Args:
-            plaintext: a `bytes` or `bytes-like` object.
+            plaintext (bytes): a `bytes` or `bytes-like` object.
 
         Returns:
-            encrypted bytes object.
+            bytes: encrypted bytes object.
 
         Raises:
             ValueError:
-                if the message is too long to encrypt with
-                the given key.
+                if the message is too long for the key to encrypt.
         """
         try:
             return self._cipher.encrypt(plaintext)
         except ValueError as e:
-            raise ValueError('the message is too long') from e
+            raise ValueError("the message is too long") from e
 
 
-class RSADecryptionCtx(CipherContext):
+class RSADecryptionCtx(_CipherContext):
     def decrypt(self, ciphertext):
         """Decrypts the ciphertext and returns the plaintext.
 
         Args:
-            ciphertext: a `bytes` or `bytes-like` object.
+            ciphertext (bytes): a `bytes` or `bytes-like` object.
 
         Returns:
-            decrypted plaintext.
+            bytes: decrypted plaintext.
 
         Raises:
             DecryptionError: if the decryption was not successful.
@@ -294,8 +329,9 @@ def _get_signer(key, pad):
             digest applied to the message.
 
             Args:
-                msghash: The Hash object used to digest the message to sign.
-                signature: The signature as bytes object.
+                msghash (:class:`pyflocker.ciphers.base.BaseHash`):
+                    The Hash object used to digest the message to sign.
+                signature (bytes, NoneType): The signature as bytes object.
                     If signature is None, signing is performed, otherwise
                     verification is performed.
 
@@ -311,47 +347,47 @@ def _get_signer(key, pad):
 
         # create an object placeholder object to hold the signer/verifier.
         funcs = dict(sign=sign_or_verify, verify=sign_or_verify)
-        svobj = type('_OpenSSLStyleSigVer', (), funcs)()
+        svobj = type("_OpenSSLStyleSigVer", (), funcs)()
         return svobj
 
     return _pad(key, mgfunc=_mgf, saltLen=pad.salt_len)
 
 
-class SigVerContext:
+class _SigVerContext:
     def __init__(self, key, padding):
         self._sig = _get_signer(key, padding)
 
 
-class RSASignerCtx(SigVerContext):
+class RSASignerCtx(_SigVerContext):
     def sign(self, msghash):
         """Return the signature of the message hash.
 
         Args:
-            msghash:
-                It must be a `Hash` object, used to digest the message to sign.
+            msghash (:class:`pyflocker.ciphers.base.BaseHash`):
+                It must be a :any:`BaseHash` object, used to digest the
+                message to sign.
 
         Returns:
-            signature of the message as bytes object.
+            bytes: signature of the message as bytes object.
 
         Raises:
-            TypeError: if the `msghash` object is not from the same
-                backend.
-            ValueError: if the key is not long enough to sign the
-                massage.
+            TypeError: if the `msghash` object is not from the same backend.
+            ValueError: if the key is not long enough to sign the massage.
         """
         try:
             return self._sig.sign(msghash)
         except ValueError as e:
-            raise ValueError('RSA key is not long enough') from e
+            raise ValueError("RSA key is not long enough") from e
 
 
-class RSAVerifierCtx(SigVerContext):
+class RSAVerifierCtx(_SigVerContext):
     def verify(self, msghash, signature):
         """Verifies the signature of the message hash.
 
         Args:
-            msghash:
-                It must be a `Hash` object, used to digest the message to sign.
+            msghash (:class:`pyflocker.ciphers.base.BaseHash`):
+                It must be a :any:`BaseHash` object, used to digest the
+                message to sign.
 
             signature:
                 signature must be a `bytes` or `bytes-like` object.
