@@ -11,7 +11,7 @@ from cryptography.hazmat.primitives.asymmetric import (
 
 from .. import base, exc, Backends
 from .._asymmetric import OAEP, MGF1, PSS
-from ._hashes import Hash
+from .Hash import Hash
 from ._serialization import encodings, private_format, public_format
 
 paddings = {
@@ -20,11 +20,13 @@ paddings = {
     PSS: pads.PSS,
 }
 
-_supported_encodings = frozenset((
-    'PEM',
-    'DER',
-    'OpenSSH',
-))
+_supported_encodings = frozenset(
+    (
+        "PEM",
+        "DER",
+        "OpenSSH",
+    )
+)
 
 
 class _RSANumbers:
@@ -49,10 +51,10 @@ class RSAPrivateKey(_RSANumbers, base.BasePrivateKey):
         if kwargs:
             # we have the key made beforehand
             # or from some classmethod
-            self._key = kwargs.pop('key')
+            self._key = kwargs.pop("key")
         else:
             if n is None:
-                raise ValueError('modulus not provided')
+                raise ValueError("modulus not provided")
             self._key = rsa.generate_private_key(e, n, defb())
 
         # numbers
@@ -71,11 +73,9 @@ class RSAPrivateKey(_RSANumbers, base.BasePrivateKey):
     def public_key(self):
         """Creates a public key from the private key
 
-        Args:
-            None
-
         Returns:
-            RSAPublicKey interface.
+            :any:`RSAPublicKey`:
+                `RSAPublicKey` interface.
         """
         return RSAPublicKey(self._key.public_key())
 
@@ -83,10 +83,11 @@ class RSAPrivateKey(_RSANumbers, base.BasePrivateKey):
         """Creates a decryption context
 
         Args:
-            padding: The padding to use. Default is OAEP.
+            padding: The padding to use. Default is `OAEP`.
 
         Returns:
-            RSADecryptionCtx for decrypting ciphertexts.
+            :any:`RSADecryptionCtx`:
+                `RSADecryptionCtx` object for decrypting ciphertexts.
         """
         return RSADecryptionCtx(self._key, padding)
 
@@ -94,38 +95,39 @@ class RSAPrivateKey(_RSANumbers, base.BasePrivateKey):
         """Create a signer context.
 
         Args:
-            padding: The padding to use. Default is PSS.
+            padding: The padding to use. Default is `PSS`.
 
         Returns:
-            A RSASignerCtx object for signing messages.
+            :any:`RSASignerCtx`:
+                A `RSASignerCtx` object for signing messages.
         """
         return RSASignerCtx(self._key, padding)
 
-    def serialize(self, encoding='PEM', format='PKCS8', passphrase=None):
+    def serialize(self, encoding="PEM", format="PKCS8", passphrase=None):
         """Serialize the private key.
 
         Args:
-            encoding: PEM or DER (defaults to PEM).
-            format: The formats can be:
-              - PKCS8 (default)
-              - TraditionalOpenSSL
-              - OpenSSH (available from pyca/cryptography version >=3.X)
-              - PKCS1 (alias to TraditionalOpenSSL for
-                PyCryptodome(x) compat)
-            passphrase:
-            A bytes-like object to protect the private key.
-            If `passphrase` is None, the private key will
-            be exported in the clear!
+            encoding (str): PEM or DER (defaults to PEM).
+            format (str): The formats can be:
+
+                - PKCS8 (default)
+                - TraditionalOpenSSL
+                - OpenSSH (available from pyca/cryptography version >=3.X)
+                - PKCS1 (alias to TraditionalOpenSSL for Cryptodome compat)
+            passphrase (bytes, bytearray, memoryview):
+                A bytes-like object to protect the private key.
+                If `passphrase` is None, the private key will
+                be exported in the clear!
 
         Returns:
-            The private key as a bytes object.
+            bytes: The private key as a bytes object.
 
         Raises:
            KeyError:
                 if the format or encoding is invalid or not supported.
         """
-        if encoding not in _supported_encodings ^ {'OpenSSH'}:
-            raise TypeError('Encoding must be PEM or DER')
+        if encoding not in _supported_encodings ^ {"OpenSSH"}:
+            raise TypeError("Encoding must be PEM or DER")
 
         encd = encodings[encoding]
         fmt = private_format[format]
@@ -133,7 +135,8 @@ class RSAPrivateKey(_RSANumbers, base.BasePrivateKey):
             prot = ser.NoEncryption()
         else:
             prot = ser.BestAvailableEncryption(
-                memoryview(passphrase).tobytes())
+                memoryview(passphrase).tobytes()
+            )
         return self._key.private_bytes(encd, fmt, prot)
 
     @classmethod
@@ -142,50 +145,55 @@ class RSAPrivateKey(_RSANumbers, base.BasePrivateKey):
         the Key interface.
 
         Args:
-            data:
+            data (bytes, bytearray):
                 The key as bytes object.
-            password:
+            password (bytes, bytearray):
                 The password that deserializes the private key.
                 `password` must be a `bytes` object if the key
                 was encrypted while serialization, otherwise `None`.
 
         Returns:
-            RSAPrivateKey interface object.
+            :any:`RSAPrivateKey`:
+                `RSAPrivateKey` object.
 
         Raises:
-            ValueError if the key could  not be deserialized.
+            ValueError: if the key could  not be deserialized.
         """
-        if data.startswith(b'-----BEGIN OPENSSH PRIVATE KEY'):
+        if data.startswith(b"-----BEGIN OPENSSH PRIVATE KEY"):
             loader = ser.load_ssh_private_key
 
-        elif data.startswith(b'-----'):
+        elif data.startswith(b"-----"):
             loader = ser.load_pem_private_key
 
         elif data[0] == 0x30:
             loader = ser.load_der_private_key
 
         else:
-            raise ValueError('incorrect key format')
+            raise ValueError("incorrect key format")
 
         # type check
         if password is not None:
             password = memoryview(password)
 
         try:
-            return cls(key=loader(
-                memoryview(data),
-                password,
-                defb(),
-            ), )
+            return cls(
+                key=loader(
+                    memoryview(data),
+                    password,
+                    defb(),
+                ),
+            )
         except (ValueError, TypeError) as e:
             raise ValueError(
-                'Cannot deserialize key. '
-                'Either Key format is invalid or '
-                'password is missing or incorrect.', ) from e
+                "Cannot deserialize key. "
+                "Either Key format is invalid or "
+                "password is missing or incorrect.",
+            ) from e
 
 
 class RSAPublicKey(_RSANumbers, base.BasePublicKey):
     """RSA Public Key wrapper class."""
+
     def __init__(self, key):
         self._key = key
 
@@ -196,7 +204,8 @@ class RSAPublicKey(_RSANumbers, base.BasePublicKey):
             padding: The padding to use. Defaults to OAEP.
 
         Returns:
-            An RSAEncryptionCtx encryption context object.
+            :any:`RSAEncryptionCtx`:
+                An `RSAEncryptionCtx` object.
         """
         return RSAEncryptionCtx(self._key, padding)
 
@@ -207,22 +216,24 @@ class RSAPublicKey(_RSANumbers, base.BasePublicKey):
             padding: The padding to use. Defaults to ECC.
 
         Returns:
-            RSAVerifierCtx verification context object.
+            :any:`RSAVerifierCtx`:
+                `RSAVerifierCtx` verification context object.
         """
         return RSAVerifierCtx(self._key, padding)
 
-    def serialize(self, encoding='PEM', format='SubjectPublicKeyInfo'):
+    def serialize(self, encoding="PEM", format="SubjectPublicKeyInfo"):
         """Serialize the public key.
 
         Args:
             encoding: PEM, DER or OpenSSH (defaults to PEM).
             format: The supported formats are:
-              - SubjectPublicKeyInfo (default)
-              - PKCS1
-              - OpenSSH
+
+                - SubjectPublicKeyInfo (default)
+                - PKCS1
+                - OpenSSH
 
         Returns:
-            Serialized public key as bytes object.
+            bytes: Serialized public key as bytes object.
 
         Raises:
             KeyError: if the encoding or format is incorrect or unsupported.
@@ -237,33 +248,34 @@ class RSAPublicKey(_RSANumbers, base.BasePublicKey):
         the Key interface.
 
         Args:
-            data:
+            data (bytes):
                 The key as bytes object.
 
         Returns:
-            RSAPublicKey key interface object.
+            :any:`RSAPublicKey`:
+                `RSAPublicKey` key object.
 
         Raises:
-            ValueError if the key could not be deserialized.
+            ValueError: if the key could not be deserialized.
         """
-        if data.startswith(b'ssh-rsa '):
+        if data.startswith(b"ssh-rsa "):
             loader = ser.load_ssh_public_key
 
-        elif data.startswith(b'-----'):
+        elif data.startswith(b"-----"):
             loader = ser.load_pem_public_key
 
         elif data[0] == 0x30:
             loader = ser.load_der_public_key
 
         else:
-            raise ValueError('incorrect key format')
+            raise ValueError("incorrect key format")
 
         try:
             return cls(key=loader(memoryview(data), defb()))
         except ValueError as e:
             raise ValueError(
-                'Cannot deserialize key. '
-                'Incorrect key format.', ) from e
+                "Cannot deserialize key. Incorrect key format.",
+            ) from e
 
 
 def _get_padding(pad):
@@ -273,11 +285,12 @@ def _get_padding(pad):
         Hash(
             pad.mgf.hash.name,
             digest_size=pad.mgf.hash.digest_size,
-        )._hasher.algorithm)
+        )._hasher.algorithm
+    )
     return _pad, mgf
 
 
-class Context:
+class _EncDecContext:
     def __init__(self, key, padding):
         pad, mgf = _get_padding(padding)
         try:
@@ -298,28 +311,30 @@ class Context:
         )
 
 
-class RSAEncryptionCtx(Context):
+class RSAEncryptionCtx(_EncDecContext):
     def encrypt(self, plaintext):
         """Encrypts the plaintext and returns the ciphertext.
 
         Args:
-            plaintext: a `bytes` or `bytes-like` object.
+            plaintext (bytes, bytearray):
+                The data to encrypt.
 
         Returns:
-            encrypted bytes object.
+            bytes: encrypted bytes object.
         """
         return self._encrypt_or_decrypt(plaintext)
 
 
-class RSADecryptionCtx(Context):
+class RSADecryptionCtx(_EncDecContext):
     def decrypt(self, ciphertext):
         """Decrypts the ciphertext and returns the plaintext.
 
         Args:
-            ciphertext: a `bytes` or `bytes-like` object.
+            ciphertext (bytes, bytearray):
+                The ciphertext to decrypt.
 
         Returns:
-            decrypted plaintext.
+            bytes: decrypted plaintext.
 
         Raises:
             DecryptionError: if the decryption was not successful.
@@ -330,11 +345,14 @@ class RSADecryptionCtx(Context):
             raise exc.DecryptionError from e
 
 
-class SigVerContext:
+class _SigVerContext:
     def __init__(self, key, padding):
         pad, mgf = _get_padding(padding)
-        salt_len = (padding.salt_len
-                    if padding.salt_len is not None else pad.MAX_LENGTH)
+        salt_len = (
+            padding.salt_len
+            if padding.salt_len is not None
+            else pad.MAX_LENGTH
+        )
 
         try:
             sig_ver = key.sign
@@ -350,20 +368,17 @@ class SigVerContext:
         )
 
 
-class RSASignerCtx(SigVerContext):
+class RSASignerCtx(_SigVerContext):
     def sign(self, msghash):
         """Return the signature of the message hash.
 
         Args:
-            msghash:
-                It must be a `Hash` object, used to digest the message to sign.
+            msghash (:class:`pyflocker.ciphers.base.BaseHash`):
+                It must be a :any:`BaseHash` object, used to digest the
+                message to sign.
 
         Returns:
-            signature of the message as bytes object.
-
-        Raises:
-            TypeError: if the `msghash` object is not from the same
-                backend.
+            bytes: signature of the message as bytes object.
         """
         if isinstance(msghash, Hash):
             hashalgo = msghash._hasher.algorithm
@@ -379,15 +394,16 @@ class RSASignerCtx(SigVerContext):
         )
 
 
-class RSAVerifierCtx(SigVerContext):
+class RSAVerifierCtx(_SigVerContext):
     def verify(self, msghash, signature):
         """Verifies the signature of the message hash.
 
         Args:
-            msghash:
-                It must be a `Hash` object, used to digest the message to sign.
+            msghash (:class:`pyflocker.ciphers.base.BaseHash`):
+                It must be a :any:`BaseHash` object, used to digest the
+                message to sign.
 
-            signature:
+            signature (bytes, bytearray):
                 signature must be a `bytes` or `bytes-like` object.
 
         Returns:
